@@ -5,6 +5,8 @@ import time
 import subprocess
 import sys
 import os
+import signal
+import atexit
 from datetime import datetime, timezone
 from typing import Optional, Dict, List, Any
 from rich.console import Console
@@ -38,6 +40,15 @@ class LiveMarketMonitor:
         self.category = category
         self.console = Console()
         
+        # Process tracking for cleanup
+        self._live_display = None
+        self._running = False
+        
+        # Register cleanup handlers
+        signal.signal(signal.SIGINT, self._signal_handler)
+        signal.signal(signal.SIGTERM, self._signal_handler)
+        atexit.register(self.cleanup)
+        
         # Initialize clients
         self.gamma_client = GammaClient(
             base_url=config.gamma_base_url,
@@ -62,6 +73,13 @@ class LiveMarketMonitor:
         self.previous_data = {}
         self.price_history = {}
         self.volume_history = {}
+    
+    def _signal_handler(self, signum, frame):
+        """Handle interrupt signals"""
+        self.console.print(f"\n[yellow]🔴 Received signal {signum}, shutting down gracefully...[/yellow]")
+        self._running = False
+        self.cleanup()
+        sys.exit(0)
         
     def get_color_indicator(self, current: float, previous: float, indicator_type: str = "price") -> str:
         """Get color-coded indicator for changes"""
@@ -141,14 +159,13 @@ class LiveMarketMonitor:
                 market_data = self.gamma_client.get_market(self.market_id)
                 return [market_data] if market_data else []
             elif self.category:
-                # Category-based monitoring
-                markets = self.aggregator.get_live_markets(
+                # Category-based monitoring - use GammaClient tag filtering directly
+                markets = self.gamma_client.get_markets(
+                    tag=self.category,
                     limit=50,
-                    require_volume=True,
-                    min_volume=0.01
+                    closed=False
                 )
-                # Filter by category
-                return [m for m in markets if m.get('category', '').lower() == self.category.lower()]
+                return markets
             else:
                 # All active markets
                 return self.aggregator.get_live_markets(
@@ -191,11 +208,18 @@ class LiveMarketMonitor:
         
         for market in markets:
             market_id = market.get("id")
-            title = market.get("question", market.get("title", ""))[:50]
             
-            # Get price data
-            outcome_prices = market.get('outcomePrices')
-            if not outcome_prices and market.get('markets') and len(market.get('markets', [])) > 0:
+            # Get title - prefer question from nested markets array, fallback to title
+            title = ""
+            if market.get('markets') and len(market.get('markets', [])) > 0:
+                title = market['markets'][0].get('question', market.get('title', ''))
+            else:
+                title = market.get('title', '')
+            title = title[:50]
+            
+            # Get price data from nested markets array
+            outcome_prices = None
+            if market.get('markets') and len(market.get('markets', [])) > 0:
                 outcome_prices = market['markets'][0].get('outcomePrices')
             
             # Parse outcome prices
@@ -279,31 +303,85 @@ class LiveMarketMonitor:
         return table
     
     def run_live_monitor(self):
-        """Run the live monitoring loop"""
+        """Run the live monitoring loop with proper cleanup"""
         self.console.print(Panel(
             "[bold red]🔴 LIVE MARKET MONITOR STARTED[/bold red]\n"
             "[dim]Press Ctrl+C to stop monitoring[/dim]",
             style="red"
         ))
         
+        self._running = True
+        
         try:
-            with Live(self.generate_live_table(), refresh_per_second=2, console=self.console) as live:
-                while True:
-                    time.sleep(0.5)  # Update every 500ms for smooth live updates
-                    live.update(self.generate_live_table())
+            # Initial data fetch to test
+            initial_data = self.get_market_data()
+            if not initial_data:
+                self.console.print(f"[red]❌ No data found for category: {self.category}[/red]")
+                self.console.print("[yellow]This might be due to API issues or no active markets[/yellow]")
+                return
+            
+            self.console.print(f"[green]✅ Found {len(initial_data)} markets to monitor[/green]")
+            
+            # Use Live display with proper cleanup
+            with Live(self.generate_live_table(), refresh_per_second=4, console=self.console) as live:
+                self._live_display = live
+                while self._running:
+                    try:
+                        live.update(self.generate_live_table())
+                        time.sleep(0.25)  # Update every 250ms for smoother live updates
+                    except Exception as e:
+                        if self._running:  # Only log errors if we're still supposed to be running
+                            self.console.print(f"[red]Update error: {e}[/red]")
+                        time.sleep(1)  # Wait a bit before retrying
         
         except KeyboardInterrupt:
-            self.console.print("\n[yellow]🔴 Live monitoring stopped[/yellow]")
+            self.console.print("\n[yellow]🔴 Live monitoring stopped by user[/yellow]")
+        except Exception as e:
+            self.console.print(f"\n[red]🔴 Live monitoring error: {e}[/red]")
         finally:
+            self._running = False
             self.cleanup()
     
     def cleanup(self):
-        """Clean up resources"""
+        """Clean up resources and ensure complete termination"""
         try:
-            self.gamma_client.close()
-            self.clob_client.close()
-        except:
+            # Stop the running flag
+            self._running = False
+            
+            # Clear the live display
+            if self._live_display:
+                self._live_display.stop()
+                self._live_display = None
+            
+            # Clear console output
+            self.console.clear()
+            
+            # Close API clients
+            if hasattr(self.gamma_client, 'close'):
+                self.gamma_client.close()
+            if hasattr(self.clob_client, 'close'):
+                self.clob_client.close()
+            if hasattr(self.subgraph_client, 'close'):
+                self.subgraph_client.close()
+            
+            # Clear state data
+            self.previous_data.clear()
+            self.price_history.clear()
+            self.volume_history.clear()
+            
+            # Force garbage collection
+            import gc
+            gc.collect()
+            
+        except Exception as e:
+            # Don't let cleanup errors prevent termination
             pass
+        
+        # Force exit to ensure complete termination
+        try:
+            os._exit(0)
+        except:
+            sys.exit(0)
 
 
 @click.command()
@@ -404,10 +482,6 @@ def live_monitor(ctx, market, category, interactive):
         
         # Launch in new terminal window
         script_content = f'''
-import sys
-import os
-sys.path.insert(0, "{os.getcwd()}")
-
 from polyterm.cli.commands.live_monitor import LiveMarketMonitor
 from polyterm.utils.config import Config
 
@@ -428,7 +502,7 @@ monitor.run_live_monitor()
         if sys.platform == "darwin":  # macOS
             subprocess.Popen([
                 "osascript", "-e", 
-                f'tell app "Terminal" to do script "cd {os.getcwd()} && python3 {script_path}"'
+                f'tell app "Terminal" to do script "python3 {script_path}"'
             ])
         elif sys.platform.startswith("linux"):  # Linux
             subprocess.Popen([
