@@ -1,6 +1,7 @@
 """TUI Screens for PolyTerm"""
 
 from .monitor import monitor_screen
+from .live_monitor import live_monitor_screen
 from .whales import whales_screen
 from .watch import watch_screen
 from .analytics import analytics_screen
@@ -11,6 +12,7 @@ from .help import help_screen
 
 __all__ = [
     "monitor_screen",
+    "live_monitor_screen",
     "whales_screen", 
     "watch_screen",
     "analytics_screen",
